Crate sorst

Crate sorst 

Enums

Directive
Error

Functions

process
Copy the contents of a reader to a writer, interpreting directives along the way.
process_dryrun
Process the contents of an input file and sink the output, returning the result.
process_file
Copy the contents an input file to a temporary file, and replaces the output path with the temporary file if the job is successful and there are changes. It’s okay for input and output to be the same path.

Type Aliases

Result